<?php
// $Id: multiple_email_edit_page.inc,v 1.1.2.3 2010/09/13 01:08:38 shawndearmond Exp $

/**
 * @file
 * Functions for the page to edit an existing email address in the registry.
 */

 /**
  * Renders the page for adding a new email address
  *
  * @return string
  */
function multiple_email_edit_page($account, $eid) {
  menu_set_active_item('user/'. $account->uid .'/edit/email-addresses/edit/'. $eid);
  return drupal_get_form('multiple_email_edit_form', $account, $eid);
}

/**
 * Builds form for editing an email address
 *
 * @ingroup forms
 * @param object $account User object
 */
function multiple_email_edit_form(&$form_state, $account, $eid) {
  $email = multiple_email_get_address($eid);
  $form['email'] = array(
    '#type' => 'textfield',
    '#title' => t('Email Address'),
    '#required' => TRUE,
    '#default_value' => $email->email,
  );

  $form['eid'] = array(
    '#type' => 'value',
    '#value' => $eid,
  );

  $form['account'] = array(
    '#type' => 'value',
    '#value' => $account,
  );

  if (user_access('administer users')) {
    $form['confirm'] = array(
      '#type' => 'checkbox',
      '#title' => t('Activate this email.'),
      '#default_value' => $email->confirmed,
    );
  }
  else {
    $form['confirm'] = array(
      '#type' => 'value',
      '#value' => $email->confirmed,
    );
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * Validates multiple_email_edit_form
 *
 * @param string $form_id
 * @param array $form_values
 */
function multiple_email_edit_form_validate($form, &$form_state) {
  if (!valid_email_address($form_state['values']['email'])) {
    form_set_error('email', t('You must enter a valid email address!'));
  }
  elseif ($form_state['values']['email'] != $form['email']['#default_value'] && multiple_email_find_address($form_state['values']['email'])) {
    form_set_error('email', t('Entered address is already registered on this site.'));
  }
}

/**
 * Processes form submission of multiple_email_edit_form
 *
 * @param string $form_id
 * @param array $form_values
 */
function multiple_email_edit_form_submit($form, &$form_state) {
  $account = $form_state['values']['account'];
  $form_state['redirect'] = check_url('user/'. $account->uid .'/email-addresses');

  if ($form['email']['#default_value'] != $form_state['values']['email']) {
    // Email address has been changed. Register Email.
    multiple_email_register_email($account->uid, $form_state['values']['email'], FALSE, $form_state['values']['eid']);
    $confirm = user_access('administer users') ? $form_state['values']['confirm'] : FALSE;
    drupal_set_message(t("The email address has been changed to '%email'.", array('%email' => $form_state['values']['email'])));
  }
  else {
    $confirm = $form_state['values']['confirm'];
    drupal_set_message(t('No change was made to the email address.'));
  }

  $email = multiple_email_get_address($form_state['values']['eid']);
  multiple_email_confirm_email($email, $confirm);

  switch ($confirm) {
    case TRUE:
      drupal_set_message(t("The email address '%email' is confirmed.", array('%email' => $form_state['values']['email'])));
      break;
    case FALSE:
      drupal_set_message(t("The email address '%email' is awaiting confirmation.", array('%email' => $form_state['values']['email'])));
      multiple_email_send_confirmation($account, multiple_email_get_address($form_state['values']['eid']));
      break;
  }
}